ble_gap_read_rem_ver_info

Function ble_gap_read_rem_ver_info 

pub unsafe extern "C" fn ble_gap_read_rem_ver_info(
    conn_handle: u16,
    version: *mut u8,
    manufacturer: *mut u16,
    subversion: *mut u16,
) -> i32
Set Read Remote Version Information is used to retrieve the version, manufacturer, and subversion information of remote controller after connection established

@param conn_handle Connection handle @param version Defines the specification version of the LE Controller @param manufacturer Indicates the manufacturer of the remote Controller @param subversion Manufacturer specific version

@return 0 on success; nonzero on failure