pub unsafe extern "C" fn ble_gap_wl_tx_add(
addrs: *const ble_addr_t,
) -> i32Expand description
Adds the address in controller’s white list.
@param addrs The entry to be added in the white list.
@return 0 on success; nonzero on failure.
pub unsafe extern "C" fn ble_gap_wl_tx_add(
addrs: *const ble_addr_t,
) -> i32Adds the address in controller’s white list.
@param addrs The entry to be added in the white list.
@return 0 on success; nonzero on failure.