pub unsafe extern "C" fn ble_gattc_disc_all_chrs(
conn_handle: u16,
start_handle: u16,
end_handle: u16,
cb: Option<unsafe extern "C" fn(u16, *const ble_gatt_error, *const ble_gatt_chr, *mut c_void) -> i32>,
cb_arg: *mut c_void,
) -> i32Expand description
Initiates GATT procedure: Discover All Characteristics of a Service.
@param conn_handle The connection over which to execute the procedure. @param start_handle The handle to begin the search at (generally the service definition handle). @param end_handle The handle to end the search at (generally the last handle in the service). @param cb The function to call to report procedure status updates; null for no callback. @param cb_arg The optional argument to pass to the callback function.
@return 0 on success; nonzero on failure.