ble_gattc_unregister_for_notification

Function ble_gattc_unregister_for_notification 

pub unsafe extern "C" fn ble_gattc_unregister_for_notification(
    conn_handle: u16,
    char_val_handle: u16,
) -> i32
Unregisters for notifications on a specified characteristic by writing to its Client Characteristic Configuration Descriptor (CCCD).

This function initiates discovery of all descriptors associated with the given characteristic value handle (char_val_handle). If a CCCD is found, it writes a value to disable notifications.

@param conn_handle The handle of the connection with the peer device. @param char_val_handle The value handle of the characteristic to unregister from notification.

@return 0 on success, non-zero error code on failure.