esp_ble_hci_trans_cfg_hs

Function esp_ble_hci_trans_cfg_hs 

pub unsafe extern "C" fn esp_ble_hci_trans_cfg_hs(
    evt_cb: Option<unsafe extern "C" fn(*mut u8, *mut c_void) -> i32>,
    evt_arg: *mut c_void,
    acl_cb: Option<unsafe extern "C" fn(*mut os_mbuf, *mut c_void) -> i32>,
    acl_arg: *mut c_void,
)
Configures the HCI transport to operate with a host. The transport will execute specified callbacks upon receiving HCI packets from the controller.

@param evt_cb The callback to execute upon receiving an HCI event. @param evt_arg Optional argument to pass to the event callback. @param acl_cb The callback to execute upon receiving ACL data. @param acl_arg Optional argument to pass to the ACL callback.