esp_ble_tx_power_get

Function esp_ble_tx_power_get 

pub unsafe extern "C" fn esp_ble_tx_power_get(power_type: u32) -> u32
@brief Get BLE TX power of the specified power type

It is recommended to use esp_ble_tx_power_get_enhanced to get TX power of individual advertising and connection handle.

@note 1. Connection TX power should only be retrieved after the connection is established. 2. If an invalid power type is provided, this API returns ESP_PWR_LVL_INVALID.

@param[in] power_type The type of TX power. It could be Advertising/Connection/Default and etc.

@return - Power level