esp_ble_tx_power_get_enhanced

Function esp_ble_tx_power_get_enhanced 

pub unsafe extern "C" fn esp_ble_tx_power_get_enhanced(
    power_type: u32,
    handle: u16,
) -> u32
@brief Get BLE TX power of the specified Advertising or Connection handle

For the TX power type: ESP_BLE_ENHANCED_PWR_TYPE_DEFAULT, ESP_BLE_ENHANCED_PWR_TYPE_SCAN, ESP_BLE_ENHANCED_PWR_TYPE_INIT, this API will ignore the input handle number.

For the TX power type: ESP_BLE_ENHANCED_PWR_TYPE_ADV and ESP_BLE_ENHANCED_PWR_TYPE_CONN, this API will return the TX power of the target handle.

@note 1. Connection Tx power should only be get after connection created. 2. If an invalid power type is provided, this API returns ESP_PWR_LVL_INVALID.

@param[in] power_type The type of TX power @param[in] handle The handle of Advertising or Connection and the value 0 for other enhanced power types

@return Power level