esp_bt_controller_deinit

Function esp_bt_controller_deinit 

pub unsafe extern "C" fn esp_bt_controller_deinit() -> i32
@brief De-initialize Bluetooth Controller to free resources and delete tasks

@note 1. You should make sure that the Controller is in idle state before de-initializing it. 2. This function should be called only once, after any other Bluetooth functions.

@return - ESP_OK: Success - ESP_ERR_INVALID_ARG: Invalid arguments - ESP_ERR_INVALID_STATE: Invalid Bluetooth Controller state - ESP_ERR_NO_MEM: Out of memory