esp_bt_controller_is_sleeping

Function esp_bt_controller_is_sleeping 

pub unsafe extern "C" fn esp_bt_controller_is_sleeping() -> bool
@brief Check if the Bluetooth Controller is currently in sleep mode when modem sleep is enabled.

@note 1. This function shall not be invoked before esp_bt_controller_enable(). 2. This function is supposed to be used ORIG mode of modem sleep.

@return - True if the Controller is in modem sleep state; false otherwise.