esp_bt_controller_wakeup_request

Function esp_bt_controller_wakeup_request 

pub unsafe extern "C" fn esp_bt_controller_wakeup_request()
@brief Request the Controller to wakeup from sleeping state during sleep mode

Profiling shows that it takes several milliseconds to wakeup from modem sleep after this request.

Generally it takes longer if 32kHz XTAL is used than the main XTAL, due to the lower frequency of the former as the bluetooth low power clock source.

@note 1. This function shall not be invoked before esp_bt_controller_enable(). 2. This function is supposed to be used ORIG mode of modem sleep. 3. After this request, the Bluetooth Controller can re-enter sleep as long as modem sleep remains enabled.