esp_nimble_hci_init

Function esp_nimble_hci_init 

pub unsafe extern "C" fn esp_nimble_hci_init() -> i32
@brief Initialize VHCI transport layer between NimBLE Host and ESP Bluetooth controller

This function initializes the transport buffers to be exchanged between NimBLE host and ESP controller. It also registers required host callbacks with the controller.

@return

  • ESP_OK if the initialization is successful
  • Appropriate error code from esp_err_t in case of an error