#[repr(C)]pub struct esp_mqtt5_connection_property_config_t {Show 15 fields
pub session_expiry_interval: u32,
pub maximum_packet_size: u32,
pub receive_maximum: u16,
pub topic_alias_maximum: u16,
pub request_resp_info: bool,
pub request_problem_info: bool,
pub user_property: *mut mqtt5_user_property_list_t,
pub will_delay_interval: u32,
pub message_expiry_interval: u32,
pub payload_format_indicator: bool,
pub content_type: *const u8,
pub response_topic: *const u8,
pub correlation_data: *const u8,
pub correlation_data_len: u16,
pub will_user_property: *mut mqtt5_user_property_list_t,
}Expand description
MQTT5 protocol connect properties and will properties configuration, more details refer to MQTT5 protocol document section 3.1.2.11 and 3.3.2.3
Fields
session_expiry_interval: u32< The interval time of session expiry
maximum_packet_size: u32< The maximum packet size that we can receive
receive_maximum: u16< The maximum pakcket count that we process concurrently
topic_alias_maximum: u16< The maximum topic alias that we support
request_resp_info: bool< This value to request Server to return Response information
request_problem_info: bool< This value to indicate whether the reason string or user properties are sent in case of failures
user_property: *mut mqtt5_user_property_list_t< The handle for user property, call function esp_mqtt5_client_set_user_property to set it
will_delay_interval: u32< The time interval that server delays publishing will message
message_expiry_interval: u32< The time interval that message expiry
payload_format_indicator: bool< This value is to indicator will message payload format
content_type: *const u8< This value is to indicator will message content type, use a MIME content type string
response_topic: *const u8< Topic name for a response message
correlation_data: *const u8< Binary data for receiver to match the response message
correlation_data_len: u16< The length of correlation data
will_user_property: *mut mqtt5_user_property_list_t< The handle for will message user property, call function esp_mqtt5_client_set_user_property to set it