esp_mqtt5_publish_property_config_t

Struct esp_mqtt5_publish_property_config_t 

#[repr(C)]
pub struct esp_mqtt5_publish_property_config_t { pub payload_format_indicator: bool, pub message_expiry_interval: u32, pub topic_alias: u16, pub response_topic: *const u8, pub correlation_data: *const u8, pub correlation_data_len: u16, pub content_type: *const u8, pub user_property: *mut mqtt5_user_property_list_t, }
MQTT5 protocol publish properties configuration, more details refer to MQTT5 protocol document section 3.3.2.3

Fields

payload_format_indicator: bool

< This value is to indicator publish message payload format

message_expiry_interval: u32

< The time interval that message expiry

topic_alias: u16

< An interger value to identify the topic instead of using topic name string

response_topic: *const u8

< Topic name for a response message

correlation_data: *const u8

< Binary data for receiver to match the response message

correlation_data_len: u16

< The length of correlation data

content_type: *const u8

< This value is to indicator publish message content type, use a MIME content type string

user_property: *mut mqtt5_user_property_list_t

< The handle for user property, call function esp_mqtt5_client_set_user_property to set it