pub unsafe extern "C" fn ble_gattc_exchange_mtu(
conn_handle: u16,
cb: Option<unsafe extern "C" fn(u16, *const ble_gatt_error, u16, *mut c_void) -> i32>,
cb_arg: *mut c_void,
) -> i32Expand description
Initiates GATT procedure: Exchange MTU.
@param conn_handle The connection over which to execute the procedure. @param cb The function to call to report procedure status updates; null for no callback. @param cb_arg The optional argument to pass to the callback function.
@return 0 on success; nonzero on failure.