pub unsafe extern "C" fn ble_hs_get_enabled_state() -> u8Expand description
Get the current enabled state of the BLE host.
In dynamic memory mode, the host state is stored in a dynamically allocated context. Returns the current value of the enabled_state field. If the context or its internal variables are not yet initialized, 0 is returned.