pub unsafe extern "C" fn ble_hs_hci_set_host_feature(
bit_num: u8,
bit_val: u8,
) -> i32Expand description
Instructs the controller to set or clear a bit controlled by the Host in the Link Layer FeatureSet stored in the Controller.
@param bit_num Bit position in the FeatureSet. @param bit_val 0: The Host feature is disabled; 1: The Host feature is enabled. @return 0 on success, error code on failure