pub unsafe extern "C" fn esp_ble_tx_power_set_enhanced(
power_type: u32,
handle: u16,
power_level: u32,
) -> i32Expand description
@brief Set BLE TX power for the specified Advertising or Connection handle
For the TX power type: ESP_BLE_ENHANCED_PWR_TYPE_DEFAULT, ESP_BLE_ENHANCED_PWR_TYPE_SCAN, ESP_BLE_ENHANCED_PWR_TYPE_INIT,
this API will ignore the input handle number, and set 0 internally.
For the TX power type: ESP_BLE_ENHANCED_PWR_TYPE_ADV and ESP_BLE_ENHANCED_PWR_TYPE_CONN,
this API will set the TX power for the target handle.
@note 1. Connection TX power should only be set after connection created.
@param[in] power_type The type of TX power @param[in] handle The handle of Advertising or Connection @param[in] power_level Power level (index) corresponding to absolute value (dBm)
@return - ESP_OK: Success - ESP_ERR_NOT_SUPPORTED: Invalid TX power type - ESP_FAIL: Failure due to other reasons