pub unsafe extern "C" fn esp_bt_controller_init(
cfg: *mut esp_bt_controller_config_t,
) -> i32Expand description
@brief Initialize the Bluetooth Controller to allocate tasks and other resources
@note This function should be called only once, before any other Bluetooth functions.
@param[in] cfg Initial Bluetooth Controller configuration
@return - ESP_OK: Success - ESP_ERR_INVALID_STATE: Invalid Bluetooth Controller state - ESP_ERR_NOT_SUPPORTED: Invalid Bluetooth Controller mode - ESP_ERR_INVALID_ARG: Invalid arguments - ESP_ERR_NO_MEM: Out of memory - ESP_FAIL: Failure due to other reasons