pub unsafe extern "C" fn esp_bt_get_lpclk_src() -> u32Expand description
@brief Get the Bluetooth sleep clock source.
@note This function shall not be invoked before esp_bt_controller_init().
@return clock source used in Bluetooth low power mode
pub unsafe extern "C" fn esp_bt_get_lpclk_src() -> u32@brief Get the Bluetooth sleep clock source.
@note This function shall not be invoked before esp_bt_controller_init().
@return clock source used in Bluetooth low power mode